@@ -6,9 +6,9 @@ use warnings;
 use Geo::UK::Postcode::Regex::Hash;
 
 use base 'Exporter';
-our @EXPORT_OK = qw/ is_valid_pc is_strict_pc is_lax_pc %REGEXES /;
+our @EXPORT_OK = qw( is_valid_pc is_strict_pc is_lax_pc %REGEXES );
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 =encoding utf-8
 
@@ -52,7 +52,7 @@ See L<Geo::UK::Postcode::Regex::Simple> for an alternative interface.
 
     ## VALIDATION METHODS
 
-    use Geo::UK::Postcode::Regex qw/ is_valid_pc is_strict_pc is_lax_pc /;
+    use Geo::UK::Postcode::Regex qw( is_valid_pc is_strict_pc is_lax_pc );
 
     if (is_valid_pc("GE0 1UK")) {
         ...
@@ -169,6 +169,29 @@ Also can determine the posttown(s) from a postcode.
 Districts and post town information taken from:
 L<https://en.wikipedia.org/wiki/Postcode_districts>
 
+=head1 IMPORTANT CHANGES FOR VERSION 0.014
+
+Please note that various bugfixes have changed the following:
+
+=over
+
+=item *
+
+Unanchored regular expressions no longer match valid postcodes within invalid
+ones.
+
+=item *
+
+Unanchored regular expressions in partial mode now can match a valid or strict
+outcode with an invalid incode.
+
+=back
+
+Please get in touch if you have any questions.
+
+See L<Geo::UK::Postcode::Regex::Simple> for other changes affecting the Simple
+interface.
+
 =head1 NOTES AND LIMITATIONS
 
 When parsing a partial postcode, whitespace may be required to separate the
@@ -211,20 +234,16 @@ our %COMPONENTS = (
 );
 
 my %BASE_REGEXES = (
-    full          => ' %s %s     \s* %s %s      ',
-    partial       => ' %s %s (?: \s* %s %s? ) ? ',
+    full          => ' %s %s     \s* %s    %s       ',
+    partial       => ' %s %s (?: \s* %s (?:%s)? ) ? ',
 );
 
 my ( %POSTTOWNS, %OUTCODES );
 
 tie our %REGEXES, 'Geo::UK::Postcode::Regex::Hash', _fetch => sub {
-    Geo::UK::Postcode::Regex->_get_re(shift);
-};
+    my ($key) = @_;
 
-sub _get_re {
-    my ( $class, $key ) = @_;
-
-    $class->_outcode_data() if $key =~ m/valid/ && !%OUTCODES;
+    _outcode_data() if $key =~ m/valid/ && !%OUTCODES;
 
     my $type = $key =~ m/lax/ ? 'lax' : 'strict';
 
@@ -232,8 +251,8 @@ sub _get_re {
 
     my @comps
         = $key =~ m/valid/
-        ? @{$components}{qw/ outcodes blank sector unit /}
-        : @{$components}{qw/ area district sector unit /};
+        ? @{$components}{qw( outcodes blank sector unit )}
+        : @{$components}{qw( area district sector unit )};
 
     @comps = map { $_ ? "($_)" : $_ } @comps if $key =~ m/captures/;
 
@@ -241,16 +260,22 @@ sub _get_re {
 
     my $re = sprintf( $BASE_REGEXES{$size}, @comps );
 
-    $re = '^' . $re . '$' if $key =~ m/anchored/;
+    if ( $key =~ m/anchored/ ) {
+        $re = '^' . $re . '$';
+
+    } elsif ( $key =~ m/extract/ ) {
+        $re = '(?:[^0-9A-Z]|\b) (' . $re . ') (?:[^0-9A-Z]|\b)';
+
+    } else {
+        $re = '(?:[^0-9A-Z]|\b) ' . $re . ' (?:[^0-9A-Z]|\b)';
+    }
 
     return $key =~ m/case-insensitive/ ? qr/$re/ix : qr/$re/x;
-}
+};
 
 ## OUTCODE AND POSTTOWN DATA
 
 sub _outcode_data {
-    my $class = shift;
-
     my %area_districts;
 
     # Get outcodes from __DATA__
@@ -349,15 +374,15 @@ Alternative way to access the regexes.
 =cut
 
 sub is_valid_pc {
-    my $pc = @_ > 1 ? $_[1] : $_[0];
+    my $pc = @_ > 1 ? $_[1] : $_[0]; # back-compat: can call as class method
     return $pc =~ $REGEXES{valid_anchored} ? 1 : 0
 }
 sub is_strict_pc {
-    my $pc = @_ > 1 ? $_[1] : $_[0];
+    my $pc = @_ > 1 ? $_[1] : $_[0]; # back-compat: can call as class method
     return $pc =~ $REGEXES{strict_anchored} ? 1 : 0
 }
 sub is_lax_pc {
-    my $pc = @_ > 1 ? $_[1] : $_[0];
+    my $pc = @_ > 1 ? $_[1] : $_[0]; # back-compat: can call as class method
     return $pc =~ $REGEXES{lax_anchored} ? 1 : 0
 }
 
@@ -403,16 +428,17 @@ Returns a list of full postcodes extracted from a string.
 sub extract {
     my ( $class, $string, $options ) = @_;
 
-    $class->_outcode_data() unless %OUTCODES;
+    _outcode_data() unless %OUTCODES;
 
     my $key
         = $options->{valid}  ? 'valid'
         : $options->{strict} ? 'strict'
         :                      'lax';
 
-    $string = uc $string if $options->{'case-insensitive'};
+    $key .= '_case-insensitive' if $options->{'case-insensitive'};
+    $key .= '_extract';
 
-    my @extracted = $string =~ m/($REGEXES{$key})/g;
+    my @extracted = $string =~ m/$REGEXES{$key}/g;
 
     return map {uc} @extracted;
 }
@@ -422,7 +448,7 @@ sub extract {
     my $parsed = Geo::UK::Postcode::Regex->parse( $pc, \%options );
 
 Returns hashref of the constituent parts - see SYNOPSIS. Missing parts will be
-set as undefined. 
+set as undefined.
 
 =cut
 
@@ -557,7 +583,7 @@ Hashref of posttown to outcode(s);
 sub outcodes_lookup {
     my $class = shift;
 
-    $class->_outcode_data() unless %OUTCODES;
+    _outcode_data() unless %OUTCODES;
 
     return \%OUTCODES;
 }
@@ -565,7 +591,7 @@ sub outcodes_lookup {
 sub posttowns_lookup {
     my $class = shift;
 
-    $class->_outcode_data() unless %POSTTOWNS;
+    _outcode_data() unless %POSTTOWNS;
 
     return \%POSTTOWNS;
 }
@@ -623,7 +649,7 @@ Michael Jemmeson E<lt>mjemmeson@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2014- Michael Jemmeson
+Copyright 2015- Michael Jemmeson
 
 =head1 LICENSE
 
